# xdow
 Video Downloader (Mostly Porn)
 <br>
 <br>
<p>This is a video downloader for porn. To download youtube videos you
can use <a href="https://pypi.org/project/youtube_dl/">youtube-dl</a> </p>
<br>
<br>
<h2>How to use</h2>
<p>Get Direct link of any video and pass the link as argument to console script <b>xdow</b></p>
<p>e.g</p>
<code>xdow https://www.pornhub.com/view_video.php?viewkey=ph5e5afa917d4fd</code>

